/* $Id: zlf.h,v 1.6 2000/02/28 17:38:34 asv Exp $ */
/****************************************************************************
*                                                                           *
*  ZLF.H                                                                    *
*                                                                           *
*  Header file of the ZLib File I/O module. This module implements the      *
*  reading and writing of optionally zlib-compressed files.                 *
*                                                                           *
*  February 2000, Alexandre Sieira Vilar <asv@tecgraf.puc-rio.br>           *
*                                                                           *
*****************************************************************************/
/*
    ZLib File I/O - A small library to read and write zlib-compressed files
    Copyright (C) 1999  TecGraf (http://www.tecgraf.puc-rio.br)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef ZLF_H
#define ZLF_H

/* for the definition of size_t */
#include <stdio.h>

typedef struct _ZLF_File ZLF_File;

/* ZLF_open 'mode' parameter constants */
enum {
	ZLF_READ,	/* opens an existing file for reading */
	ZLF_WRITE	/* creates a new file for writing */
};

/* ZLF_open 'comp' parameter constants */
enum {
	ZLF_PLAIN=0,	/* performs no compression or decompression */
	ZLF_ZLIB=1	/* performs compression or decompression */
};

/*
 * ZLF_open( name, mode, comp )
 *	Opens the file specified by 'name'. 
 *	'mode' must equal ZLF_READ or ZLF_WRITE, indicating the mode of
 *	operation desired. If a file is opened for reading, all write
 *	operations will be invalid, and vice-versa.
 *	'comp' must equal ZLF_PLAIN or ZLF_ZLIB, indicating wether the
 *	data must be processed by zlib or not. When zlib is not used, the
 *	data is read or written directly, as if the standard I/O routines 
 *	were being used.
 *	On error, returns NULL. Otherwise, returns a valid instance of
 *	ZLF_File.
 */
ZLF_File * ZLF_open( const char *name, int mode, int comp );

/*
 * ZLF_close( file )
 *	Closes a file opened by ZLF_open, flushing all pending I/O and
 *	releasing any resources.
 *	Returns zero if successful and non-zero on error.
 */
int ZLF_close( ZLF_File *file );

/*
 * ZLF_eof( file )
 *	Returns non-zero if a read operation has occurred past the end of the
 *	file data, or zero otherwise.
 *	This operation only works on files opened with ZLF_READ mode, and
 *	always returns non-zero on files opened with ZLF_WRITE mode.
 */
int ZLF_eof( ZLF_File *file );

/*
 * ZLF_error( file )
 *	Returns non-zero if an error ocurred while processing the file, or
 *	zero otherwise.
 */
int ZLF_error( ZLF_File *file );

/*
 * ZLF_tell( file )
 *	Returns the file position indicator for the stream. If an error occurs,
 *	returns -1.
 */
int ZLF_tell( ZLF_File *file );

/*
 * ZLF_read( file, ptr, size )
 *	Reads 'size' bytes, from the file pointed to by 'file', storing
 *	them at the location given by 'ptr'.
 *	This operation only works on files opened with ZLF_READ mode.
 *	Returns the number of bytes successfully read, or a smaller value
 *	if an error or the end of file are found.
 */
size_t ZLF_read( ZLF_File *file, void *ptr, size_t size );

/*
 * ZLF_getc( file )
 *	Reads the next character from 'file' and returns it as an unsigned
 *	char cast to an int, or EOF on end of file or error.
 *
 *	This operation only works on files opened with ZLF_READ mode.
 */
int ZLF_getc( ZLF_File *file );

/*
 * ZLF_peek( file )
 *	Reads the next character from 'file' and returns it as an unsigned
 *	char cast to an int, or EOF on end of file or error. Unlike ZLF_getc,
 *	this function does not remove the character from the stream.
 *
 *	This operation only works on files opened with ZLF_READ mode.
 */
int ZLF_peek( ZLF_File *file );

/*
 * ZLF_write( file, ptr, size )
 *	Writes 'size' bytes, to the file pointed to by 'file',
 *	obtaining them from the location given by 'ptr'.
 *	This operations only works on files opened with ZLF_WRITE mode.
 *	Returns the number of bytes successfully written, or a shorter value
 *	on error.
 */
size_t ZLF_write( ZLF_File *file, const void *ptr, size_t size );

/*
 * ZLF_putc( file, c )
 *	Writes the character 'c', cast to an unsigned char, to 'file'.
 *	This operations only works on files opened with ZLF_WRITE mode.
 *	Returns the character written as an unsigned char cast to an int
 *	or EOF on error.
 */
int ZLF_putc( ZLF_File *file, int c );

#endif

